package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysCategory;

/**
 * 类别Service接口
 * 
 * @author ruoyi
 * @date 2024-08-22
 */
public interface ISysCategoryService 
{
    /**
     * 查询类别
     * 
     * @param id 类别主键
     * @return 类别
     */
    public SysCategory selectSysCategoryById(Long id);

    /**
     * 查询类别列表
     * 
     * @param sysCategory 类别
     * @return 类别集合
     */
    public List<SysCategory> selectSysCategoryList(SysCategory sysCategory);

    /**
     * 新增类别
     * 
     * @param sysCategory 类别
     * @return 结果
     */
    public int insertSysCategory(SysCategory sysCategory);

    /**
     * 修改类别
     * 
     * @param sysCategory 类别
     * @return 结果
     */
    public int updateSysCategory(SysCategory sysCategory);

    /**
     * 批量删除类别
     * 
     * @param ids 需要删除的类别主键集合
     * @return 结果
     */
    public int deleteSysCategoryByIds(Long[] ids);

    /**
     * 删除类别信息
     * 
     * @param id 类别主键
     * @return 结果
     */
    public int deleteSysCategoryById(Long id);
}
