package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysCategory;
import com.ruoyi.system.service.ISysCategoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 类别Controller
 * 
 * @author ruoyi
 * @date 2024-08-22
 */
@RestController
@RequestMapping("/system/category")
public class SysCategoryController extends BaseController
{
    @Autowired
    private ISysCategoryService sysCategoryService;

    /**
     * 查询类别列表
     */
    @PreAuthorize("@ss.hasPermi('system:category:list')")
    @GetMapping("/list")
    public AjaxResult list(SysCategory sysCategory)
    {
        List<SysCategory> list = sysCategoryService.selectSysCategoryList(sysCategory);
        return AjaxResult.success(list);
    }

    /**
     * 导出类别列表
     */
    @PreAuthorize("@ss.hasPermi('system:category:export')")
    @Log(title = "类别", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysCategory sysCategory)
    {
        List<SysCategory> list = sysCategoryService.selectSysCategoryList(sysCategory);
        ExcelUtil<SysCategory> util = new ExcelUtil<SysCategory>(SysCategory.class);
        util.exportExcel(response, list, "类别数据");
    }

    /**
     * 获取类别详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:category:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(sysCategoryService.selectSysCategoryById(id));
    }

    /**
     * 新增类别
     */
    @PreAuthorize("@ss.hasPermi('system:category:add')")
    @Log(title = "类别", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysCategory sysCategory)
    {
        return toAjax(sysCategoryService.insertSysCategory(sysCategory));
    }

    /**
     * 修改类别
     */
    @PreAuthorize("@ss.hasPermi('system:category:edit')")
    @Log(title = "类别", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysCategory sysCategory)
    {
        return toAjax(sysCategoryService.updateSysCategory(sysCategory));
    }

    /**
     * 删除类别
     */
    @PreAuthorize("@ss.hasPermi('system:category:remove')")
    @Log(title = "类别", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysCategoryService.deleteSysCategoryByIds(ids));
    }
}
